from subprocess import Popen, PIPE


def stringToJSON(string):
    if not string in ['{}']:
        string = string.replace('{  ', '')
        string = string.replace('}', '')
        string = string.replace('"', '')
        string = string.split(",  ")
        stringList = [i.split(': ') for i in string]
        outDictList = []
        for i in stringList:
            outDictList.append({i[0]: i[1].rstrip().lstrip()})
        return outDictList
    else:
        return {}


def outputStripper(result):
    result = result.split('Result:\n\n')[1].split('\n\n> ')[0].replace('\n', '')
    result = stringToJSON(result)
    return result


def removeSpeacialChars(address):
    b = {'≈': '', '≠': '', '>': '', '<': '', '+': '', '≥': '', '≤': '', '±': '', '*': '', '÷': '', '√': '',
         '°': '', '⊥': '', '~': '', 'Δ': '', 'π': '', '≡': '', '≜': '', '∝': '', '∞': '', '≪': '', '≫': '',
         '⌈': '', '⌉': '', '⌋': '', '⌊': '', '∑': '', '∏': '', 'γ': '', 'φ': '', '⊃': '', '⋂': '', '⋃': '',
         'μ': '', 'σ': '', 'ρ': '', 'λ': '', 'χ': '', '⊄': '', '⊆': '', '⊂': '', '⊇': '', '⊅': '', '⊖': '',
         '∈': '', '∉': '', '⊕': '', '⇒': '', '⇔': '', '↔': '', '∀': '', '∃': '', '∄': '', '∴': '', '∵': '',
         'ε': '', '∫': '', '∮': '', '∯': '', '∰': '', 'δ': '', 'ψ': '', 'Θ': '', 'θ': '', 'α': '', 'β': '',
         'ζ': '', 'η': '', 'ι': '', 'κ': '', 'ξ': '', 'τ': '', 'ω': '', '∇': ''}
    for x, y in b.items():
        address = address.replace(x, y)
    return address


class AddressParser:

    def __init__(self):
        self.exePath = r"C:\Workbench\libpostal\src\address_parser.exe"
        self.process = Popen(self.exePath, shell=False, universal_newlines=True,
                             stdin=PIPE, stdout=PIPE, stderr=PIPE)
        pass

    def runParser(self, address):
        address = removeSpeacialChars(address)
        address = address + '\n'
        self.process.stdin.write(address)
        self.process.stdin.flush()

        result = ''
        for line in self.process.stdout:
            if line == '}\n':
                result += line
                break
            result += line
        return outputStripper(result)

    def terminateParser(self):
        self.process.stdin.close()
        self.process.terminate()
        self.process.wait()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pypostalwin",  # This is the name of the package
    version="0.0.2",  # The initial release version
    author="Tamil Selvan A V",  # Full name of the author
    description=" python package for libpostal wrapper only for windows",
    url="https://github.com/selva221724/pypostalwin",
    license="MIT",
    include_package_data=True,
    long_description=long_description,  # Long description read from the the readme file
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),  # List of all python modules to be installed
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Framework :: IPython",
        "Operating System :: Microsoft :: Windows :: Windows 10",
        "Intended Audience :: Science/Research",
        "Intended Audience :: Developers",
        "Topic :: Scientific/Engineering",
        "Environment :: Console"
    ],  # Information to filter the project on PyPi website
    python_requires='>=3.6',  # Minimum version requirement of the package
    py_modules=["pypostalwin"],  # Name of the python package
    package_dir={'': 'pypostalwin/src'},  # Directory of the source code of the package

)
